/***************************************************************************
 *            tv.h
 *
 *  Tue Jul  5 12:43:04 2005
 *  Copyright  2005  Fabio Marzocca
 *  Email
 ****************************************************************************/
#ifndef BAOBAB_TV_H
#define BAOBAB_TV_H

#include <gtk/gtk.h>

/* tree model columns (_H_ are hidden) */
enum
{
	COL_DIR_NAME,
	COL_H_FULLPATH,
	COL_BAR,
	COL_H_PERC,
	COL_DIR_SIZE,
	COL_H_SIZE,
	COL_PERC,
	COL_H_ALLOCSIZE,
	COL_ELEMENTS,
	COL_H_ELEMENTS,
	COL_HARDLINK,
	COL_H_HARDLINK,
	NUM_TREE_COLUMNS
	
};

/* search model columns */
enum
{
  COL0_ICON,
  COL1_STRING,
  COL2_STRING,
  COL_FULLPATH,
  COL_LASTACCESS,
  COL_SIZE,
  COL_FILETYPE,
  COL_OWNER,	
  NUM_COLUMNS
};



GtkWidget* create_directorytreeview(void);

GtkWidget* create_tree_filesearch (void);

#endif
